INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES ('core_main_quickcreate_classified', 'classified', 'Post a New Listing', 'Classified_Plugin_Menus::canCreateClassifieds', '{"route":"classified_general","action":"create","icon":"fi fi-rr-document"}', 'core_main_quickcreate', '', 4);

UPDATE `engine4_core_menuitems` SET `params` = '{"route":"classified_general","icon":"fi fi-rr-document"}' WHERE `engine4_core_menuitems`.`name` = 'core_main_classified';

UPDATE `engine4_core_menuitems` SET `description` = 'Post goods & services in a trusted marketplace' WHERE `engine4_core_menuitems`.`name` = 'core_main_classified';