
/* Fix some incorrect default collations */
ALTER TABLE `engine4_classified_fields_maps` DEFAULT CHARSET=utf8mb4 COLLATE utf8mb4_unicode_ci ;
ALTER TABLE `engine4_classified_fields_search` DEFAULT CHARSET=utf8mb4 COLLATE utf8mb4_unicode_ci ;
